==> pdfjs-dist-5.0.375.jar: META-INF/resources/webjars/pdfjs-dist/5.0.375/types/src/pdf.d.ts <==
export type OnProgressParameters = import("./display/api").OnProgressParameters;
export type PDFDocumentLoadingTask = import("./display/api").PDFDocumentLoadingTask;
export type PDFDocumentProxy = import("./display/api").PDFDocumentProxy;
export type PDFPageProxy = import("./display/api").PDFPageProxy;
export type RenderTask = import("./display/api").RenderTask;
export type PageViewport = import("./display/display_utils").PageViewport;
import { AbortException } from "./shared/util.js";
import { AnnotationEditorLayer } from "./display/editor/annotation_editor_layer.js";
import { AnnotationEditorParamsType } from "./shared/util.js";
import { AnnotationEditorType } from "./shared/util.js";
import { AnnotationEditorUIManager } from "./display/editor/tools.js";
import { AnnotationLayer } from "./display/annotation_layer.js";
import { AnnotationMode } from "./shared/util.js";
import { AnnotationType } from "./shared/util.js";
import { build } from "./display/api.js";
import { ColorPicker } from "./display/editor/color_picker.js";
import { createValidAbsoluteUrl } from "./shared/util.js";
import { DOMSVGFactory } from "./display/svg_factory.js";
import { DrawLayer } from "./display/draw_layer.js";
import { FeatureTest } from "./shared/util.js";
import { fetchData } from "./display/display_utils.js";
import { getDocument } from "./display/api.js";
import { getFilenameFromUrl } from "./display/display_utils.js";
import { getPdfFilenameFromUrl } from "./display/display_utils.js";
import { getUuid } from "./shared/util.js";
import { getXfaPageViewport } from "./display/display_utils.js";
import { GlobalWorkerOptions } from "./display/worker_options.js";
import { ImageKind } from "./shared/util.js";
import { InvalidPDFException } from "./shared/util.js";
import { isDataScheme } from "./display/display_utils.js";
import { isPdfFile } from "./display/display_utils.js";
import { isValidExplicitDest } from "./display/api.js";
import { MathClamp } from "./shared/util.js";
import { noContextMenu } from "./display/display_utils.js";
import { normalizeUnicode } from "./shared/util.js";
import { OPS } from "./shared/util.js";
import { OutputScale } from "./display/display_utils.js";
import { PasswordResponses } from "./shared/util.js";
import { PDFDataRangeTransport } from "./display/api.js";
import { PDFDateString } from "./display/display_utils.js";
import { PDFWorker } from "./display/api.js";
import { PermissionFlag } from "./shared/util.js";
import { PixelsPerInch } from "./display/display_utils.js";
import { RenderingCancelledException } from "./display/display_utils.js";
import { ResponseException } from "./shared/util.js";
import { setLayerDimensions } from "./display/display_utils.js";
import { shadow } from "./shared/util.js";
import { SignatureExtractor } from "./display/editor/drawers/signaturedraw.js";
import { stopEvent } from "./display/display_utils.js";
import { SupportedImageMimeTypes } from "./display/display_utils.js";
import { TextLayer } from "./display/text_layer.js";
import { TouchManager } from "./display/touch_manager.js";
import { Util } from "./shared/util.js";
import { VerbosityLevel } from "./shared/util.js";
import { version } from "./display/api.js";
import { XfaLayer } from "./display/xfa_layer.js";
export { AbortException, AnnotationEditorLayer, AnnotationEditorParamsType, AnnotationEditorType, AnnotationEditorUIManager, AnnotationLayer, AnnotationMode, AnnotationType, build, ColorPicker, createValidAbsoluteUrl, DOMSVGFactory, DrawLayer, FeatureTest, fetchData, getDocument, getFilenameFromUrl, getPdfFilenameFromUrl, getUuid, getXfaPageViewport, GlobalWorkerOptions, ImageKind, InvalidPDFException, isDataScheme, isPdfFile, isValidExplicitDest, MathClamp, noContextMenu, normalizeUnicode, OPS, OutputScale, PasswordResponses, PDFDataRangeTransport, PDFDateString, PDFWorker, PermissionFlag, PixelsPerInch, RenderingCancelledException, ResponseException, setLayerDimensions, shadow, SignatureExtractor, stopEvent, SupportedImageMimeTypes, TextLayer, TouchManager, Util, VerbosityLevel, version, XfaLayer };

==> pdfjs-dist-5.2.133.jar: META-INF/resources/webjars/pdfjs-dist/5.2.133/types/src/pdf.d.ts <==
export type OnProgressParameters = import("./display/api").OnProgressParameters;
export type PDFDocumentLoadingTask = import("./display/api").PDFDocumentLoadingTask;
export type PDFDocumentProxy = import("./display/api").PDFDocumentProxy;
export type PDFPageProxy = import("./display/api").PDFPageProxy;
export type RenderTask = import("./display/api").RenderTask;
export type PageViewport = import("./display/display_utils").PageViewport;
import { AbortException } from "./shared/util.js";
import { AnnotationEditorLayer } from "./display/editor/annotation_editor_layer.js";
import { AnnotationEditorParamsType } from "./shared/util.js";
import { AnnotationEditorType } from "./shared/util.js";
import { AnnotationEditorUIManager } from "./display/editor/tools.js";
import { AnnotationLayer } from "./display/annotation_layer.js";
import { AnnotationMode } from "./shared/util.js";
import { AnnotationType } from "./shared/util.js";
import { build } from "./display/api.js";
import { ColorPicker } from "./display/editor/color_picker.js";
import { createValidAbsoluteUrl } from "./shared/util.js";
import { DOMSVGFactory } from "./display/svg_factory.js";
import { DrawLayer } from "./display/draw_layer.js";
import { FeatureTest } from "./shared/util.js";
import { fetchData } from "./display/display_utils.js";
import { getDocument } from "./display/api.js";
import { getFilenameFromUrl } from "./display/display_utils.js";
import { getPdfFilenameFromUrl } from "./display/display_utils.js";
import { getUuid } from "./shared/util.js";
import { getXfaPageViewport } from "./display/display_utils.js";
import { GlobalWorkerOptions } from "./display/worker_options.js";
import { ImageKind } from "./shared/util.js";
import { InvalidPDFException } from "./shared/util.js";
import { isDataScheme } from "./display/display_utils.js";
import { isPdfFile } from "./display/display_utils.js";
import { isValidExplicitDest } from "./display/api.js";
import { MathClamp } from "./shared/util.js";
import { noContextMenu } from "./display/display_utils.js";
import { normalizeUnicode } from "./shared/util.js";
import { OPS } from "./shared/util.js";
import { OutputScale } from "./display/display_utils.js";
import { PasswordResponses } from "./shared/util.js";
import { PDFDataRangeTransport } from "./display/api.js";
import { PDFDateString } from "./display/display_utils.js";
import { PDFWorker } from "./display/api.js";
import { PermissionFlag } from "./shared/util.js";
import { PixelsPerInch } from "./display/display_utils.js";
import { RenderingCancelledException } from "./display/display_utils.js";
import { ResponseException } from "./shared/util.js";
import { setLayerDimensions } from "./display/display_utils.js";
import { shadow } from "./shared/util.js";
import { SignatureExtractor } from "./display/editor/drawers/signaturedraw.js";
import { stopEvent } from "./display/display_utils.js";
import { SupportedImageMimeTypes } from "./display/display_utils.js";
import { TextLayer } from "./display/text_layer.js";
import { TouchManager } from "./display/touch_manager.js";
import { updateUrlHash } from "./shared/util.js";
import { Util } from "./shared/util.js";
import { VerbosityLevel } from "./shared/util.js";
import { version } from "./display/api.js";
import { XfaLayer } from "./display/xfa_layer.js";
export { AbortException, AnnotationEditorLayer, AnnotationEditorParamsType, AnnotationEditorType, AnnotationEditorUIManager, AnnotationLayer, AnnotationMode, AnnotationType, build, ColorPicker, createValidAbsoluteUrl, DOMSVGFactory, DrawLayer, FeatureTest, fetchData, getDocument, getFilenameFromUrl, getPdfFilenameFromUrl, getUuid, getXfaPageViewport, GlobalWorkerOptions, ImageKind, InvalidPDFException, isDataScheme, isPdfFile, isValidExplicitDest, MathClamp, noContextMenu, normalizeUnicode, OPS, OutputScale, PasswordResponses, PDFDataRangeTransport, PDFDateString, PDFWorker, PermissionFlag, PixelsPerInch, RenderingCancelledException, ResponseException, setLayerDimensions, shadow, SignatureExtractor, stopEvent, SupportedImageMimeTypes, TextLayer, TouchManager, updateUrlHash, Util, VerbosityLevel, version, XfaLayer };
